# EIDA Consistency Report: `BGR`

- Seed: `214412`
- Time: `2025-09-08T17:01:39.743741+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `15`
- Inconsistent: `5`
- Score: **75.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `5`

## Dataselect Response Types
- **SingleTrace**: `20`

---

## Detailed Results
### `SX.LEUT..BHE`
- Window: `2023-06-14T07:16:05 → 2023-06-14T07:26:05`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `BQ.HILG..HHE`
- Window: `2023-03-01T14:13:12 → 2023-03-01T14:23:12`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GR.NOTT..HHE`
- Window: `2006-01-24T21:12:55 → 2006-01-24T21:22:55`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `SX.TRIB..HHE`
- Window: `2024-09-06T07:48:24 → 2024-09-06T07:58:24`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `GR.BKS1..EHZ`
- Window: `2015-07-18T19:27:36 → 2015-07-18T19:37:36`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `TH.WARTH..BHZ`
- Window: `2023-02-14T12:28:43 → 2023-02-14T12:38:43`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `TH.BONN..HHZ`
- Window: `2025-07-08T05:26:46 → 2025-07-08T05:36:46`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HS.MESS..HHE`
- Window: `2016-12-19T10:17:53 → 2016-12-19T10:27:53`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `SX.LEUT..BHZ`
- Window: `2023-05-31T19:54:12 → 2023-05-31T20:04:12`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `LE.PEB..HHN`
- Window: `2023-01-09T16:01:00 → 2023-01-09T16:11:00`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GR.FSHA..SHZ`
- Window: `2024-03-10T13:07:33 → 2024-03-10T13:17:33`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `GR.I26H4..BDF`
- Window: `2006-03-10T04:33:58 → 2006-03-10T04:43:58`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `TH.LAWA..HHE`
- Window: `2011-06-12T07:40:56 → 2011-06-12T07:50:56`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `TH.MLFH..HHE`
- Window: `2025-08-09T04:28:59 → 2025-08-09T04:38:59`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `GR.GEC1..SHZ`
- Window: `2004-02-26T20:29:10 → 2004-02-26T20:39:10`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `YD.BGK18..EHN`
- Window: `2021-06-27T03:39:00 → 2021-06-27T03:49:00`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `LE.TRIT..EHN`
- Window: `2024-03-30T09:12:01 → 2024-03-30T09:22:01`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `LE.ROTT..EH1`
- Window: `2016-02-05T03:25:46 → 2016-02-05T03:35:46`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GR.INS3..SHZ`
- Window: `2013-12-21T13:55:02 → 2013-12-21T14:05:02`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `GR.GRA4..HHZ`
- Window: `2019-12-25T08:03:30 → 2019-12-25T08:13:30`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
